==> haskell-infinite-list-0.1.1-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-infinite-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 infinite-list
version:              0.1.1
visibility:           public
id:                   infinite-list-0.1.1-Gor9J1uoEkH5PsOumtyJAi
key:                  infinite-list-0.1.1-Gor9J1uoEkH5PsOumtyJAi
license:              BSD-3-Clause
maintainer:           andrew.lelechenko@gmail.com
author:               Bodigrim
homepage:             https://github.com/Bodigrim/infinite-list
synopsis:             Infinite lists
description:
    Modern lightweight library for infinite lists with fusion:

    * API similar to "Data.List".
    * No non-boot dependencies.
    * Top performance, driven by fusion.
    * Avoid dangerous instances like `Foldable`.
    * Use `NonEmpty` where applicable.
    * Use `Word` for indices.
    * Be lazy, but not too lazy.

    @
    {\-# LANGUAGE PostfixOperators #-\}
    import Data.List.Infinite (Infinite(..), (...), (....))
    import qualified Data.List.Infinite as Inf
    @

category:             Data
abi:                  d64dc056282ff7232ff60a5797dc31bf
exposed:              True
exposed-modules:      Data.List.Infinite
hidden-modules:       Data.List.Infinite.Zip Data.List.Infinite.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/infinite-list-0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/infinite-list-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-infinite-list
hs-libraries:         HSinfinite-list-0.1.1-Gor9J1uoEkH5PsOumtyJAi
depends:              base-4.16.4.0
haddock-interfaces:
    /usr/share/doc/haskell-infinite-list/html/infinite-list.haddock

haddock-html:         /usr/share/doc/haskell-infinite-list/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-infinite-list-0.1.1-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-infinite-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 infinite-list
version:              0.1.1
visibility:           public
id:                   infinite-list-0.1.1-KLWiLUdHOt2DKm20lIwhuR
key:                  infinite-list-0.1.1-KLWiLUdHOt2DKm20lIwhuR
license:              BSD-3-Clause
maintainer:           andrew.lelechenko@gmail.com
author:               Bodigrim
homepage:             https://github.com/Bodigrim/infinite-list
synopsis:             Infinite lists
description:
    Modern lightweight library for infinite lists with fusion:

    * API similar to "Data.List".
    * No non-boot dependencies.
    * Top performance, driven by fusion.
    * Avoid dangerous instances like `Foldable`.
    * Use `NonEmpty` where applicable.
    * Use `Word` for indices.
    * Be lazy, but not too lazy.

    @
    {\-# LANGUAGE PostfixOperators #-\}
    import Data.List.Infinite (Infinite(..), (...), (....))
    import qualified Data.List.Infinite as Inf
    @

category:             Data
abi:                  30e697f180d5327f0a1abbcdcf6abb3e
exposed:              True
exposed-modules:      Data.List.Infinite
hidden-modules:       Data.List.Infinite.Zip Data.List.Infinite.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/infinite-list-0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/infinite-list-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-infinite-list
hs-libraries:         HSinfinite-list-0.1.1-KLWiLUdHOt2DKm20lIwhuR
depends:              base-4.16.4.0
haddock-interfaces:
    /usr/share/doc/haskell-infinite-list/html/infinite-list.haddock

haddock-html:         /usr/share/doc/haskell-infinite-list/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
